@@ -1,5 +1,5 @@
 package Net::Whois::Raw::Data;
-$Net::Whois::Raw::Data::VERSION = '2.93';
+$Net::Whois::Raw::Data::VERSION = '2.94';
 # ABSTRACT: Config for Net::Whois::Raw.
 
 use utf8;
@@ -163,6 +163,7 @@ our %servers = qw(
     CAPITAL         whois.donuts.co
     CARDS           whois.donuts.co
     CARE            whois.donuts.co
+    CAFE            whois.donuts.co
     CAREERS         whois.donuts.co
     CASH            whois.donuts.co
     CATERING        whois.donuts.co
@@ -477,6 +478,7 @@ our %servers = qw(
     PR  whois.nic.pr
     PT  whois.dns.pt
     PW  whois.centralnic.com
+    QA  whois.registry.qa
     RE  whois.nic.re
     RO  whois.rotld.ro
     RS  whois.rnids.rs
@@ -863,7 +865,7 @@ our %notfound = (
     'whois.nic.wien'             => 'No match',
 
     'whois.publicinterestregistry.net' => 'NOT FOUND',
-    'whois-dub.mm-registry.com'        => 'Status: Not Registered',
+    'whois-dub.mm-registry.com'        => 'The queried object does not exist',
 
     'whois.nic.ag'            => 'NOT FOUND',
     'whois.nic.as'            => 'Domain Not Found',
@@ -1031,6 +1033,7 @@ our %notfound = (
     'whois.nic.moscow'            => 'No entries found for the selected source',
     'whois.nic.tatar'             => 'No entries found for the selected source',
     'whois.nic.press'             => 'DOMAIN NOT FOUND',
+    'whois.registry.qa'           => 'No Data Found',
 );
 
 # Common whois stripping REs
@@ -2643,7 +2646,7 @@ Net::Whois::Raw::Data - Config for Net::Whois::Raw.
 
 =head1 VERSION
 
-version 2.93
+version 2.94
 
 =head1 AUTHOR
 
